#
# spec file for package python-google-cloud-kms
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-google-cloud-kms
Version:        2.21.4
Release:        1.2
Summary:        Cloud Key Management Service (KMS) API API client library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/GoogleCloudPlatform/google-cloud-python
Source:         https://files.pythonhosted.org/packages/source/g/google-cloud-kms/google-cloud-kms-%{version}.tar.gz
BuildRequires:  %{python_module google-api-core >= 1.34.1}
BuildRequires:  %{python_module grpc-google-iam-v1 >= 0.12.4}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module proto-plus >= 1.22.3}
BuildRequires:  %{python_module protobuf >= 3.19}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-google-api-core >= 1.34.1
Requires:       python-google-auth
Requires:       python-grpc-google-iam-v1 >= 0.12.4
Requires:       python-proto-plus >= 1.22.3
Requires(post): update-alternatives
Requires(preun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Cloud Key Management Service (KMS) API API client library

%prep
%setup -q -n google-cloud-kms-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest tests/unit

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/google/cloud/kms
%{python_sitelib}/google/cloud/kms_v1
%{python_sitelib}/google_cloud_kms-%{version}.dist-info

%changelog
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 2.21.4:
  * in google.cloud.kms.v1.PublicKey, pem field is always populated
  * Require google-api-core>=1.34.1 (#12307) (be87bc4)
  * fix ValueError in test__validate_universe_domain
* Mon Feb 26 2024 Robert Schweikert <rjschwei@suse.com>
- Include in SLE 15 SP4 and later (jsc#PED-6697)
* Sun Feb  4 2024 Dirk Müller <dmueller@suse.com>
- update to 2.21.0:
  * Allow users to explicitly configure universe domain
* Sat Dec 16 2023 Dirk Müller <dmueller@suse.com>
- update to 2.20.0:
  * Require proto-plus >= 1.22.3
  * Use retry_async instead of retry in async client
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 2.19.2:
  * Add support for python 3.12
  * Introduce compatibility with native namespace packages
* Wed Aug 30 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.19.1
  * Minor formatting (#411)
- from version 2.19.0
  * Add interoperable symmetric encryption system (#403)
* Tue Jul 18 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.18.0
  * Add interoperable symmetric encryption system (#396)
  * Add async context manager return types (#398)
* Tue May 30 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.17.0
  * Added VerifyConnectivity RPC (#388)
* Thu Mar 30 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.16.1
  * Publish the API comment changes related to supporting different hash
    functions/values for ECDSA signing (#386)
- from version 2.16.0
  * Add support for Coordinated External Keys (#382)
  * Fix formatting of request arg in docstring (#385)
* Wed Mar  1 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.15.0
  * Enable "rest" transport in Python for services supporting numeric enums (#377)
- from version 2.14.1
  * Add context manager return types (8137467)
  * Add documentation for enums (8137467)
- from version 2.14.0
  * Add support for python 3.11 (#368)
* Fri Jan  6 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.13.0
  * Add SHA-2 import methods (6311278)
  * Add support for `google.cloud.kms.__version__` (6311278)
  * Add support for additional HMAC algorithms (6311278)
  * Add typing to proto.Message based class attributes (6311278)
  * Add dict typing for client_options (6311278)
  * **deps:** Require google-api-core &gt;=1.34.0, >=2.11.0  (dbe2f96)
  * Drop usage of pkg_resources (dbe2f96)
  * Fix timeout default values (dbe2f96)
  * **samples:** Snippetgen handling of repeated enum field (6311278)
  * **samples:** Snippetgen should call await on the operation
    coroutine before calling result (dbe2f96)
- Drop installation of fixup_kms_v1_keywords.py, removed upstream
- Update BuildRequires and Requires from setup.py
* Mon Oct 17 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.12.3
  * **deps:** Allow protobuf 3.19.5 (#350)
- from version 2.12.2
  * **deps:** Require protobuf >= 3.20.2 (#347)
* Wed Sep 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- 2.12.1 (2022-08-11)
  Bug Fixes
  deps: allow protobuf < 5.0.0 (#322) (229e0f5)
  deps: require proto-plus >= 1.22.0 (229e0f5)
- 2.12.0 (2022-07-14)
  Features
  add audience parameter (06a4096)
  Bug Fixes
  deps: require google-api-core>=1.32.0,>=2.8.0 (#315) (82ab556)
  require python 3.7+ (#313) (28d244f)
* Thu Jun  9 2022 pgajdos@suse.com
- run just unit tests
* Wed Jun  8 2022 pgajdos@suse.com
- version update to 2.11.2
  * lot of changes, see
    https://github.com/googleapis/python-kms/blob/main/CHANGELOG.md
- python-mock is not required for build
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Wed Apr  8 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.3.0
  * add ProtectionLevel.External enum; standardize use of 'optional'
    and 'required' in docstrings (via synth)
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.1:
  * Remove send/recv msg size limit (via synth). (#8959)
  * Accomodate new location of 'IAMPolicyStub' (via synth). (#8679)
  * Add 'options_' argument to client's 'get_iam_policy'; pin black version (via synth). (#8656)
  * Add 'client_options' support, update list method docstrings (via synth). (#8514)
* Tue Jul  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.1.0:
  * Allow kwargs to be passed to create_channel (via synth). (#8395)
  * Add empty lines (via synth). (#8062)
  * Remove classifier for Python 3.4 for end-of-life. (#7535)
* Mon Feb 18 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.0.0
